summaryrefslogtreecommitdiff
diff options
context:
space:
mode:
authorGregory Wlodarek <gregory.wlodarek@mongodb.com>2022-01-12 19:31:08 +0000
committerEvergreen Agent <no-reply@evergreen.mongodb.com>2022-01-12 21:12:56 +0000
commitd186067e1d81467e585204087e2757875b7aa8c6 (patch)
tree4101dcaba7c772afe7954d907bdea3941b0bd3a2
parentf5e953fa99885a6cf02a3e8504e7979b7a5eedd8 (diff)
downloadmongo-d186067e1d81467e585204087e2757875b7aa8c6.tar.gz
SERVER-62550 Lower BSONColumn roundtrip memory usage in validate
-rw-r--r--src/mongo/db/catalog/collection_validation.cpp4
1 files changed, 2 insertions, 2 deletions
diff --git a/src/mongo/db/catalog/collection_validation.cpp b/src/mongo/db/catalog/collection_validation.cpp
index 6e58918350c..318b682689c 100644
--- a/src/mongo/db/catalog/collection_validation.cpp
+++ b/src/mongo/db/catalog/collection_validation.cpp
@@ -464,9 +464,9 @@ void _validateBSONColumnRoundtrip(OperationContext* opCtx,
// This function is memory intensive as it needs to store the original documents prior to
// compressing and decompressing them to check that the documents are the same afterwards. We'll
// limit the number of original documents we hold in-memory to be approximately 100MB to avoid
// running out of memory.
- constexpr size_t kMaxMemoryUsageBytes = 100 * 1024 * 1024;
+ constexpr size_t kMaxMemoryUsageBytes = 25 * 1024 * 1024;
size_t currentMemoryUsageBytes = 0;
BSONColumnBuilder columnBuilder("");
@@ -464,9 +464,9 @@ void _validateBSONColumnRoundtrip(OperationContext* opCtx,
// This function is memory intensive as it needs to store the original documents prior to
// compressing and decompressing them to check that the documents are the same afterwards. We'll
- // limit the number of original documents we hold in-memory to be approximately 100MB to avoid
+ // limit the number of original documents we hold in-memory to be approximately 25MB to avoid
// running out of memory.